==> _private_chat-1.0.21.tar.gz: lib/call/call_helper.dart <==
import 'dart:async'; 
import 'package:cloud_firestore/cloud_firestore.dart';
import 'package:_private_chat/utils/utils.dart';
import 'package:_private_core_network/network_resources/resources.dart';
import 'package:_private_core/_private_core.dart';
import 'package:_private_chat/constant.dart';

CollectionReference get _callCollection =>
    FirebaseFirestore.instance.collection(kCollectionCALLS);
CollectionReference get _callStatesCollection =>
    FirebaseFirestore.instance.collection(kCollectionCALLSTATES);

class CallHelper {
  static Stream<DocumentSnapshot> callCommingStream() =>
      _callCollection.doc(loggedUsername).snapshots();

  static Future<DocumentSnapshot> callComingGet() =>
      _callCollection.doc(loggedUsername).get();

  static Stream<DocumentSnapshot> callStateStream(id) =>
      _callStatesCollection.doc(id).snapshots();

  static Future updateCallState(id, {status, pickedAt, endAt, infoCall}) async {
    Map<String, dynamic> data = {};
    if (status != null) data.addAll({kDbSTATUS: status});
    if (pickedAt != null) data.addAll({kDbPICKEDAT: pickedAt});
    if (endAt != null) data.addAll({kDbENDAT: endAt});
    if (infoCall != null) data.addAll({kDbCALLINFO: infoCall});
    _callStatesCollection.doc(id).set(data, SetOptions(merge: true));
  }

  static Future<Call?> dial({
    required String receiverId,
    required String? receiverName,
    String? callerId,
    String? callerName,
    String? callerPic,
    String? receiverPic,
    bool? isVideoCall = true,
    Map? data,
  }) async {
    Call? call;
    int timestamp = DateTime.now().millisecondsSinceEpoch;
    String channelName = '$loggedUsername-$timestamp';
    AgoraToken? agoraToken = await AgoraRepo().generateToken(channelName);
    if (agoraToken == null) {
      // AppUtils.showTopMessage(title: 'Token empty');
      return call;
    }
    call = Call(
      timeepoch: timestamp,
      callerId: callerId ?? loggedUsername,
      callerName: callerName ?? '${appPrefs.loginUser!.displayName}',
      callerPic: callerPic ?? appPrefs.loginUser!.thumbnail,
      receiverId: receiverId,
      receiverName: receiverName,
      receiverPic: receiverPic,
      channelId: channelName,
      channelToken: agoraToken.token,
      agoraAppId: agoraToken.appId,
      isVideoCall: isVideoCall,
      data: data,
    );
    await _makeCall(call: call);

    updateCallState(channelName,
        infoCall: call.toJson(),
        status: kCallStateCALLING,
        pickedAt: 0,
        endAt: 0);

    call.hasDialled = true;
    return call;
  }

  static Future _makeCall({required Call call}) async {
    try {
      await _callCollection.doc(call.callerId).delete();
      await _callCollection.doc(call.receiverId).delete();

      call.hasDialled = true;
      Map<String, dynamic> hasDialledMap = call.toJson();

      call.hasDialled = false;
      Map<String, dynamic> hasNotDialledMap = call.toJson();

      await _callCollection
          .doc(call.callerId)
          .set(hasDialledMap, SetOptions(merge: true));

      await _callCollection
          .doc(call.receiverId)
          .set(hasNotDialledMap, SetOptions(merge: true));
    } catch (e) {}
  }

  static Future endCall({required Call call, required status}) async {
    try {
      await _callCollection.doc(call.callerId).delete();
      await _callCollection.doc(call.receiverId).delete();
      await updateCallState(call.channelId, status: status);
    } catch (e) {}
  }
}

class Call {
  String? callerId;
  String? callerName;
  String? callerPic;
  String? receiverId;
  String? receiverName;
  String? receiverPic;
  String? agoraAppId;
  String? channelId;
  String? channelToken;
  int? timeepoch;
  bool? hasDialled;
  bool? isVideoCall;

  //Payload data
  Map? data;

  Call({
    this.callerId,
    this.callerName,
    this.callerPic,
    this.receiverId,
    this.receiverName,
    this.receiverPic,
    this.timeepoch,
    this.channelId,
    this.hasDialled,
    this.isVideoCall,
    this.channelToken,
    this.agoraAppId,
    this.data,
  });

  Map<String, dynamic> toJson() {
    Map<String, dynamic> json = Map();
    json["callerId"] = callerId;
    json["callerName"] = callerName;
    json["callerPic"] = callerPic;
    json["receiverId"] = receiverId;
    json["receiverName"] = receiverName;
    json["receiverPic"] = receiverPic;
    json["channelId"] = channelId;
    json["hasDialled"] = hasDialled;
    json["isVideoCall"] = isVideoCall;
    json["timeepoch"] = timeepoch;
    json["channelToken"] = channelToken;
    json["agoraAppId"] = agoraAppId;
    json["data"] = data;
    return json;
  }

  Call.fromJson(json) {
    callerId = json["callerId"];
    callerName = json["callerName"];
    callerPic = json["callerPic"];
    receiverId = json["receiverId"];
    receiverName = json["receiverName"];
    receiverPic = json["receiverPic"];
    channelId = json["channelId"];
    hasDialled = json["hasDialled"];
    isVideoCall = json["isVideoCall"];
    timeepoch = json["timeepoch"];
    channelToken = json["channelToken"];
    agoraAppId = json["agoraAppId"];
    data = json["data"];
  }
}

==> _private_chat-1.0.31.tar.gz: lib/call/call_helper.dart <==
import 'dart:async';
import 'package:cloud_firestore/cloud_firestore.dart';
import 'package:_private_chat/utils/utils.dart';
import 'package:_private_core_network/network_resources/resources.dart';
import 'package:_private_core/_private_core.dart';
import 'package:_private_chat/constant.dart';

import '../firestore_resouce/instances.dart';

class CallHelper {
  static Stream<DocumentSnapshot> callCommingStream() =>
      colCALLS.doc(loggedUsername).snapshots();

  static Future<DocumentSnapshot> callComingGet() =>
      colCALLS.doc(loggedUsername).get();

  static Stream<DocumentSnapshot> callStateStream(id) =>
      colCALLSTATES.doc(id).snapshots();

  static Future updateCallState(id, {status, pickedAt, endAt, infoCall}) async {
    Map<String, dynamic> data = {};
    if (status != null) data.addAll({kDbSTATUS: status});
    if (pickedAt != null) data.addAll({kDbPICKEDAT: pickedAt});
    if (endAt != null) data.addAll({kDbENDAT: endAt});
    if (infoCall != null) data.addAll({kDbCALLINFO: infoCall});
    colCALLSTATES.doc(id).set(data, SetOptions(merge: true));
  }

  static Future<Call?> dial({
    required String receiverId,
    required String? receiverName,
    String? callerId,
    String? callerName,
    String? callerPic,
    String? receiverPic,
    bool? isVideoCall = true,
    Map? data,
  }) async {
    Call? call;
    int timestamp = DateTime.now().millisecondsSinceEpoch;
    String channelName = '$loggedUsername-$timestamp';
    AgoraToken? agoraToken = await AgoraRepo().generateToken(channelName);
    if (agoraToken == null) {
      // AppUtils.showTopMessage(title: 'Token empty');
      return call;
    }
    call = Call(
      timeepoch: timestamp,
      callerId: callerId ?? loggedUsername,
      callerName: callerName ?? '${appPrefs.loginUser!.displayName}',
      callerPic: callerPic ?? appPrefs.loginUser!.thumbnail,
      receiverId: receiverId,
      receiverName: receiverName,
      receiverPic: receiverPic,
      channelId: channelName,
      channelToken: agoraToken.token,
      agoraAppId: agoraToken.appId,
      isVideoCall: isVideoCall,
      data: data,
    );
    await _makeCall(call: call);

    updateCallState(channelName,
        infoCall: call.toJson(),
        status: kCallStateCALLING,
        pickedAt: 0,
        endAt: 0);

    call.hasDialled = true;
    return call;
  }

  static Future _makeCall({required Call call}) async {
    try {
      await colCALLS.doc(call.callerId).delete();
      await colCALLS.doc(call.receiverId).delete();

      call.hasDialled = true;
      Map<String, dynamic> hasDialledMap = call.toJson();

      call.hasDialled = false;
      Map<String, dynamic> hasNotDialledMap = call.toJson();

      await colCALLS
          .doc(call.callerId)
          .set(hasDialledMap, SetOptions(merge: true));

      await colCALLS
          .doc(call.receiverId)
          .set(hasNotDialledMap, SetOptions(merge: true));
    } catch (e) {}
  }

  static Future endCall({required Call call, required status}) async {
    try {
      await colCALLS.doc(call.callerId).delete();
      await colCALLS.doc(call.receiverId).delete();
      await updateCallState(call.channelId, status: status);
    } catch (e) {}
  }
}

class Call {
  String? callerId;
  String? callerName;
  String? callerPic;
  String? receiverId;
  String? receiverName;
  String? receiverPic;
  String? agoraAppId;
  String? channelId;
  String? channelToken;
  int? timeepoch;
  bool? hasDialled;
  bool? isVideoCall;

  //Payload data
  Map? data;

  Call({
    this.callerId,
    this.callerName,
    this.callerPic,
    this.receiverId,
    this.receiverName,
    this.receiverPic,
    this.timeepoch,
    this.channelId,
    this.hasDialled,
    this.isVideoCall,
    this.channelToken,
    this.agoraAppId,
    this.data,
  });

  Map<String, dynamic> toJson() {
    Map<String, dynamic> json = Map();
    json["callerId"] = callerId;
    json["callerName"] = callerName;
    json["callerPic"] = callerPic;
    json["receiverId"] = receiverId;
    json["receiverName"] = receiverName;
    json["receiverPic"] = receiverPic;
    json["channelId"] = channelId;
    json["hasDialled"] = hasDialled;
    json["isVideoCall"] = isVideoCall;
    json["timeepoch"] = timeepoch;
    json["channelToken"] = channelToken;
    json["agoraAppId"] = agoraAppId;
    json["data"] = data;
    return json;
  }

  Call.fromJson(json) {
    callerId = json["callerId"];
    callerName = json["callerName"];
    callerPic = json["callerPic"];
    receiverId = json["receiverId"];
    receiverName = json["receiverName"];
    receiverPic = json["receiverPic"];
    channelId = json["channelId"];
    hasDialled = json["hasDialled"];
    isVideoCall = json["isVideoCall"];
    timeepoch = json["timeepoch"];
    channelToken = json["channelToken"];
    agoraAppId = json["agoraAppId"];
    data = json["data"];
  }
}
